# Generated by Django 2.1.5 on 2019-01-09 16:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('site_parameters', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SiteSocialNetwork',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('order_in_list', models.PositiveIntegerField(default=0, verbose_name='Order in List')),
                ('service', models.CharField(help_text='The name of the service (e.g., Facebook, YouTube)', max_length=250, verbose_name='Site Name')),
                ('title_on_service', models.CharField(help_text='The page title WC uses at the service', max_length=250, verbose_name='Title of WorldChannel Page')),
                ('url', models.URLField(help_text="The URL of WC's page on the service.", max_length=250, verbose_name='URL')),
                ('svg_path', models.TextField(blank=True, help_text='You need to be superuser to edit this.', null=True, verbose_name='SVG Path')),
            ],
            options={
                'verbose_name': 'Social Media Site',
                'verbose_name_plural': 'Social Media Sites',
                'abstract': False,
            },
        ),
    ]



from django.conf import settings

from .models import (
    SiteNavigationSection, SiteNavigationSectionItem, SiteParameterImage,
    SiteParameterInteger, SiteParameterString, SiteParameterSwitch, SiteParameterText,
    SiteParameterURL, SiteSocialNetwork
)


def get_custom_site_parameters(request):
    global_items = {}

    #### NAVS AND MENUS
    # This is based on the SiteNavigationSection model, which is basically a sub-menu of items grouped somewhere on a page.
    #   For WC2, there are two header Sections ("top" and "main")
    #   There are also THREE footer Sections ("left", "middle", and "right")
    #
    # Since you can presumably add more of these in different places, I've made the setting of the context variable generic;
    # the variable name is 'global_nav_' + the slug of the navigation menu.
    #
    navs = SiteNavigationSection.objects.filter(available_globally=True)
    for nav in navs:
        nav_items = SiteNavigationSectionItem.objects.filter(
            navigation_menu__slug=nav.slug
        ).filter(order_in_menu__gt=0).order_by('-order_in_menu')
        key = 'global_nav_' + nav.slug.replace('-', '_')
        global_items[key] = nav_items

    #########################################
    # GLOBAL STRINGS
    #       This are set in the global context with keys of site_parameter_string.string_slug_with_underscores_in_place_of_hyphens
    #
    #########################################
    try:
        site_strings = SiteParameterString.objects.all()
        d = {}
        for s in site_strings:
            d[s.slug.replace('-', '_')] = s.value
        global_items['site_parameter_string'] = d
    except:
        global_items['site_parameter_string'] = None

    ##########################################
    # GLOBAL IMAGES
    #
    ##########################################
    the_icons = SiteParameterImage.objects.all()
    for icon in the_icons:
        tag = icon.slug.replace('-', '_')
        #if tag == 'pbs_passport_icon':
        #    tag = 'passport_icon'
        if tag == 'default-canonical-image':
            global_items['default_canonical_image'] = icon.value
        global_items[tag] = icon.value

    ##########################################
    # GLOBAL TEXTS
    #   These are like Strings above, except they COME OUT AS HTML.
    ##########################################
    site_texts = SiteParameterText.objects.all()
    d = {}
    for text in site_texts:
        d[text.slug.replace('-', '_')] = text.value
    global_items['site_parameter_texts'] = d

    ##########################################
    # GLOBAL NUMBERS
    ##########################################
    site_numbers = SiteParameterInteger.objects.all()
    d = {}
    for number in site_numbers:
        d[number.slug.replace('-', '_')] = number.value
    global_items['site_parameter_numbers'] = d

    ##########################################
    # GLOBAL SWITCHES
    ##########################################
    site_switches = SiteParameterSwitch.objects.all()
    d = {}
    for sw in site_switches:
        d[sw.slug.replace('-', '_')] = sw.value
    global_items['site_parameter_switches'] = d

    ##########################################
    # GLOBAL EXTERNAL URL
    ##########################################
    site_external_urls = SiteParameterURL.objects.all()
    d = {}
    for url in site_external_urls:
        d[url.slug.replace('-', '_')] = url
    global_items['external_site'] = d

    ###### SOCIAL MEDIA THINGS
    # Get the social network items
    social_networks = SiteSocialNetwork.objects.filter(available=True
                                                      ).order_by('order_in_list')
    global_items['global_social_media'] = social_networks
    social_media = {}
    for network in social_networks:
        social_media[network.slug] = network
    global_items['global_social_media_dict'] = social_media

    try:
        default_social_media_description = SiteParameterString.objects.get(
            slug='social-media-default-description'
        )
        global_items['default_social_media_description'
                    ] = default_social_media_description.value
    except:
        global_items['default_social_media_description'] = 'Site Social Media'

    return global_items



from django.db import models
from django.utils.translation import ugettext_lazy as _

from .abstract_models import (
    BaseControlledVocabulary, BaseGenericModel, BaseOrderedModel, BaseSlugModel,
    BaseTimeStampModel, BaseTitleModel
)


class AbstractSiteParameter(BaseTimeStampModel, BaseTitleModel, BaseSlugModel):
    """
    All site parameters, regardless of type have:
        date_created and date_modified,
        title and slug
    """
    pass

    class Meta:
        abstract = True

    def __str__(self):
        return self.title


class SiteNavigationSection(BaseControlledVocabulary):
    """
    This model handles clusters of navigation items, e.g., parts of the header or footer,
    but they can also be other customized navs.

    Items in the navs needn't be monogamous.

    """
    available_globally = models.BooleanField(
        _('Global Menu'),
        default=True,
        help_text='Should this menu be available across the entire site?'
    )

    class Meta:
        verbose_name = 'Navigation Menu'
        verbose_name_plural = 'Navigation Menus'

    def __str__(self):
        return self.title


class SiteNavigationSectionItem(BaseTimeStampModel, BaseTitleModel):
    """
    APOLOGIA:

    If the same reference appears in >1 SiteNavigationSection instances,
    the you WILL have to make the slug unique.

    Sorry about that.

    RAD: 2018-Aug-23
    """
    url_slug = models.CharField(
        _('URL Slug'),
        max_length=100,
        null=True,
        blank=True,
        help_text=
        'If an apphook listing page, the \"name\" value from the urls.py file. (You will need to ask a developer for this.)'
    )
    internal_url = models.CharField(
        _('Internal Link'),
        max_length=100,
        null=True,
        blank=True,
        help_text=
        'Use this for directly accessing an internal page with its partial URL: e.g., \'/about\''
    )
    external_url = models.URLField(
        _('External URL'),
        max_length=250,
        null=True,
        blank=True,
        help_text='If this is an external link, put the URL here'
    )

    navigation_menu = models.ForeignKey(
        SiteNavigationSection,
        related_name='menu_items',
        on_delete=models.CASCADE,    # required for Django 2.0
    )

    order_in_menu = models.PositiveIntegerField(
        _('Menu Order'),
        null=False,
        default=0,
        help_text='Order in Menu, if > 0, highest is shown first'
    )

    class Meta:
        verbose_name = 'Navigation Menu Item'
        verbose_name_plural = 'Navigation Menu Items'


###################################### UNARY PARAMETERS BY TYPE #########################################################


class SiteParameterSwitch(AbstractSiteParameter):
    """
    Site Boolean, e.g., "show contact us on homepage"
    """
    value = models.BooleanField(
        _('Switch'), default=False, help_text="This is \'switch\' in the template tag."
    )

    class Meta:
        verbose_name = 'Site: Switch'
        verbose_name_plural = 'Site: Swtiches'


class SiteParameterURL(AbstractSiteParameter):
    """
    Site URL, e.g. "pbs-url" could be "http://www.pbs.org/"
    """
    value = models.URLField(
        _('URL'), null=True, blank=True, help_text="This is \'url\' in the template tag."
    )
    new_window = models.BooleanField(_('Opens New Browser Window'), default=True)

    class Meta:
        verbose_name = 'Site: URL Reference'
        verbose_name_plural = 'Site: URL References'


class SiteParameterInteger(AbstractSiteParameter):
    """
    Site Integer - this is good for things like establishing pagination limits, etc.
    """
    value = models.IntegerField(
        _('Number'),
        null=True,
        blank=True,
        help_text='This is \'number\' in the template tag'
    )

    class Meta:
        verbose_name = 'Site: Numbered Parameter'
        verbose_name_plural = 'Site: Numbered Parameters'


class SiteParameterText(AbstractSiteParameter):
    """
    Site Text - this might be some kind of global disclaimer message that appears in the
    footer, but you want to be able to edit/change now and then.
    """
    value = models.TextField(
        _('Text'),
        null=True,
        blank=True,
        help_text="This is \'text\' in the template tag."
    )

    class Meta:
        verbose_name = 'Site: Text Block'
        verbose_name_plural = 'Site: Text Blocks'


class SiteParameterString(AbstractSiteParameter):
    """
    Site String - this is for global labels, e.g., "site-banner-text" = "Welcome to our website!"
    """
    value = models.CharField(
        _('Value'),
        max_length=255,
        null=True,
        blank=True,
        help_text="This is \'string\' in the template tag."
    )

    class Meta:
        verbose_name = 'Site: String'
        verbose_name_plural = 'Site: Strings'


def get_upload_to(instance, filename):
    return instance.get_upload_to_path(filename)


class SiteParameterImage(AbstractSiteParameter):
    """
    Site images.

        There are two that REALLY SHOULD BE DEFINED HERE.
        1) 'default-canonical-image' should be set to an image that everything else on the site falls back to,
            when another more-appropriate image can't be found.   Aspect ratio ~ 16:9 is a good idea.
        2) 'default-poster-image' ditto, but here, aspect ratio ~ 2:3 is a good idea.
    """
    value = models.ImageField(
        _('Image'),
        width_field='image_width',
        height_field='image_height',
        upload_to=get_upload_to,
        help_text="This is \'image\' in the template tag."
    )
    image_height = models.PositiveIntegerField('Image Height', blank=True, null=True)
    image_width = models.PositiveIntegerField('Image Width', blank=True, null=True)

    class Meta:
        verbose_name = 'Site: Image'
        verbose_name_plural = 'Site: Images'

    def get_upload_to_path(self, filename):
        return 'canonical_images/site/' + filename


class AbstractSocialNetwork(BaseGenericModel, BaseOrderedModel):
    service = models.CharField(
        _('Site Name'),
        max_length=250,
        null=False,
        help_text='The name of the service (e.g., Facebook, YouTube)'
    )
    title_on_service = models.CharField(
        _('Page Title'),
        max_length=250,
        null=False,
        help_text='The page title used at the service'
    )
    url = models.URLField(
        _('URL'),
        max_length=250,
        null=False,
        help_text='The URL of this site\'s page on the service.'
    )
    svg_path = models.TextField(
        _('SVG Path'),
        null=True,
        blank=True,
    # default = 'I need to put an SVG path here...'
        help_text='You need to be superuser to edit this.'
    )

    class Meta:
        verbose_name = 'Social Media Site'
        verbose_name_plural = 'Social Media Sites'
        abstract = True

    def __str__(self):
        return "%s (%s)" % (self.service, self.url)


class SiteSocialNetwork(AbstractSocialNetwork):
    pass



# Generated by Django 2.1.5 on 2019-01-09 16:02

from django.db import migrations, models
import django.db.models.deletion
import site_parameters.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SiteNavigationSection',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('available_globally', models.BooleanField(default=True, help_text='Should this menu be available across the entire site?', verbose_name='Global Menu')),
            ],
            options={
                'verbose_name': 'Site Navigation Menu',
                'verbose_name_plural': 'Site Navigation Menus',
            },
        ),
        migrations.CreateModel(
            name='SiteNavigationSectionItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('url_slug', models.CharField(blank=True, help_text='If an apphook listing page, the "name" value from the urls.py file. (You will need to ask a developer for this.)', max_length=100, null=True, verbose_name='URL Slug')),
                ('internal_url', models.CharField(blank=True, help_text="Use this for directly accessing an internal page with its partial URL: e.g., '/about'", max_length=100, null=True, verbose_name='Internal Link')),
                ('external_url', models.URLField(blank=True, help_text='If this is an external link, put the URL here', max_length=250, null=True, verbose_name='External URL')),
                ('order_in_menu', models.PositiveIntegerField(default=0, help_text='Order in Menu, if > 0, highest is shown first', verbose_name='Menu Order')),
                ('navigation_menu', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='menu_items', to='site_parameters.SiteNavigationSection')),
            ],
            options={
                'verbose_name': 'Navigation Item',
                'verbose_name_plural': 'Navigation Items',
            },
        ),
        migrations.CreateModel(
            name='SiteParameterImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('value', models.ImageField(height_field='image_height', help_text="This is 'image' in the template tag.", upload_to=site_parameters.models.get_upload_to, verbose_name='Image', width_field='image_width')),
                ('image_height', models.PositiveIntegerField(blank=True, null=True, verbose_name='Image Height')),
                ('image_width', models.PositiveIntegerField(blank=True, null=True, verbose_name='Image Width')),
            ],
            options={
                'verbose_name': 'Site Image',
                'verbose_name_plural': 'Site Images',
            },
        ),
        migrations.CreateModel(
            name='SiteParameterInteger',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('value', models.IntegerField(blank=True, help_text="This is 'number' in the template tag", null=True, verbose_name='Number')),
            ],
            options={
                'verbose_name': 'Numbered Parameter',
                'verbose_name_plural': 'Numbered Parameters',
            },
        ),
        migrations.CreateModel(
            name='SiteParameterString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('value', models.CharField(blank=True, help_text="This is 'string' in the template tag.", max_length=255, null=True, verbose_name='Value')),
            ],
            options={
                'verbose_name': 'Site String',
                'verbose_name_plural': 'Site Strings',
            },
        ),
        migrations.CreateModel(
            name='SiteParameterSwitch',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('value', models.BooleanField(default=False, help_text="This is 'switch' in the template tag.", verbose_name='Switch')),
            ],
            options={
                'verbose_name': 'Site Switch',
                'verbose_name_plural': 'Site Swtiches',
            },
        ),
        migrations.CreateModel(
            name='SiteParameterText',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('value', models.TextField(blank=True, help_text="This is 'text' in the template tag.", null=True, verbose_name='Text')),
            ],
            options={
                'verbose_name': 'Site Text Block',
                'verbose_name_plural': 'Site Text Blocks',
            },
        ),
        migrations.CreateModel(
            name='SiteParameterURL',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('value', models.URLField(blank=True, help_text="This is 'url' in the template tag.", null=True, verbose_name='URL')),
                ('new_window', models.BooleanField(default=True, verbose_name='Opens New Browser Window')),
            ],
            options={
                'verbose_name': 'External Site URL',
                'verbose_name_plural': 'External Site URLs',
            },
        ),
    ]



from django import template
from ..helpers import find_site_parameter
from ..models import SiteNavigationSectionItem

register = template.Library()


@register.simple_tag
def lookup_site_parameter(param_type, slug, *args, **kwargs):
    default = None
    if 'default' in kwargs.keys():
        default = kwargs['default']
    value = find_site_parameter(slug=slug, param_type=param_type, default=default)
    return value


@register.simple_tag
def build_navigation_menu(slug, *args, **kwargs):
    nav_items = SiteNavigationSectionItem.objects.filter(
        navigation_menu__slug=slug
    ).filter(order_in_menu__gt=0).order_by('-order_in_menu')
    return nav_items



from django.contrib import admin, messages


class BaseAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("title", )}

    class Meta:
        abstract = True


class BaseVocabAdmin(BaseAdmin):
    prepopulated_fields = {"slug": ("title", )}
    list_display = ('pk', 'title', 'slug', 'available')
    list_display_links = ('pk', 'title')
    ordering = ('slug', )
    search_fields = [
        'title',
    ]
    readonly_fields = ('date_created', 'date_modified', 'pk')

    fieldsets = (
        (
            None,
            {
                'fields': (
                    ('pk', 'available', 'date_created', 'date_modified'),
                    ('title', 'slug'),
                ),
            },
        ),
    )

    class Meta:
        abstract = True


class BaseStatusAdmin(admin.ModelAdmin):
    actions = ['make_available', 'make_unavailable']

    def make_available(self, request, queryset):
        number_made_available = queryset.update(available=True)
        self.message_user(
            request,
            '%d page(s) made AVAILABLE' % number_made_available,
            level=messages.SUCCESS
        )

    make_available.short_description = 'Make items AVAILABLE'

    def make_unavailable(self, request, queryset):
        number_taken_offline = queryset.update(available=False)
        self.message_user(
            request,
            '%d page(s) made UNAVAILABLE.' % number_taken_offline,
            level=messages.SUCCESS
        )

    make_unavailable.short_description = 'Make items UNAVAILABLE'

    def get_actions(self, request):
        actions = super(BaseStatusAdmin, self).get_actions(request)
        if 'delete_selected' in actions.keys():
            del actions['delete_selected']
        return actions

    class Meta:
        abstract = True


class BaseParameterAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("title", )}
    list_display = ('pk', 'title', 'slug', 'value')
    list_display_links = ('pk', 'title')
    ordering = ('slug', )
    search_fields = [
        'title',
    ]
    readonly_fields = ['date_created', 'date_modified', 'pk']

    fieldsets = (
        (
            None,
            {
                'fields': (
                    ('pk', 'date_created', 'date_modified'), ('title', 'slug'),
                    ('value', )
                ),
            },
        ),
    )

    class Meta:
        abstract = True


# THE DIFFERENCE BETWEEN BaseStatusAdmin and BaseGenericStatusAdmin is that the latter has a slug field, while the former does not.
class BaseGenericStatusAdmin(BaseAdmin, BaseStatusAdmin):
    pass

    class Meta:
        abstract = True



# Generated by Django 2.1.5 on 2019-01-10 12:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('site_parameters', '0002_sitesocialnetwork'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sitesocialnetwork',
            name='title_on_service',
            field=models.CharField(help_text='The page title used at the service', max_length=250, verbose_name='Page Title'),
        ),
        migrations.AlterField(
            model_name='sitesocialnetwork',
            name='url',
            field=models.URLField(help_text="The URL of this site's page on the service.", max_length=250, verbose_name='URL'),
        ),
    ]



from .models import (
    SiteParameterSwitch, SiteParameterURL, SiteParameterInteger, SiteParameterText,
    SiteParameterString, SiteParameterImage, SiteNavigationSectionItem
)

### This is just a dict of models with keys.
PARAM_TYPES = {
    'switch': SiteParameterSwitch, 'url': SiteParameterURL,
    'number': SiteParameterInteger, 'text': SiteParameterText,
    'string': SiteParameterString, 'image': SiteParameterImage
}


def find_site_parameter(slug=None, default=None, param_type=None):
    """
    Look up a site parameter by type and slug.
    If no type is given, all of them are searched.

    If the queryset is empty, then return the default value provided.

    Isn't that neat?
    """
    if not slug:    # why did you call me when you have nothing to say?
        return None
    if param_type:    # faster
        try:
            item = PARAM_TYPES[param_type].objects.get(slug=slug)
            return item.value
        except:
            return default
    else:    # slower
        for k in PARAM_TYPES.keys():
            try:
                item = PARAM_TYPES[param_type].objects.get(slug=slug)
                return item.value
            except:
                pass    # try again
    # I couldn't find anything - sorry.
    return default



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-site-parameters',
    version='0.1.4',
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    license='MIT License, see LICENSE',
    description="Django models to allow Admin-accessible global site parameters",
    long_description=README,
    long_description_content_type='text/markdown',
    url='http://github.com/wgbh/django-site-parameters/',
    author='Bob Donahue',
    author_email='bob_donahue@wgbh.org',
    install_requires=[
        'Pillow',
        'pytz',
    ],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Framework :: Django :: 2.1',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



from django.contrib import admin
from .abstract_admin import BaseParameterAdmin, BaseGenericStatusAdmin
from .models import (
    SiteParameterSwitch, SiteParameterURL, SiteParameterInteger, SiteParameterText,
    SiteParameterString, SiteParameterImage, SiteNavigationSectionItem,
    SiteNavigationSection, SiteSocialNetwork
)


class SiteNavigationSectionItemInline(admin.StackedInline):
    model = SiteNavigationSectionItem
    extra = 0
    ordering = ['-order_in_menu']
    fieldsets = (
        (
            None,
            {
                'fields': (('title', 'order_in_menu'), ),
            },
        ),
        (
            'Overall',
            {
                'fields': (
                    'url_slug',
                    'internal_url',
                    'external_url',
                ),
                'description': "If this is a listing page from an apphook, put the \"name\" value from the urls.py file in the URL Slug field and leave External URL blank. Otherwise either put the partial URL in the Internal URL field (e.g., \'/about\'), or the complete URL in the external URL field."
            },
        ),
    )


class SiteNavigationSectionAdmin(admin.ModelAdmin):
    list_display = (
        'pk',
        'title',
    )
    list_display_links = ('pk', 'title')
    prepopulated_fields = {"slug": ("title", )}
    inlines = [
        SiteNavigationSectionItemInline,
    ]
    fieldsets = ((None, {'fields': (
        ('title', 'slug'),
        'available_globally',
    )}), )
    ordering = [
        'pk',
    ]


class SiteNavigationSectionItemAdmin(admin.ModelAdmin):
    list_display = ('pk', 'title', 'url_slug', 'internal_url', 'external_url')
    list_display_links = ('pk', 'title')
    #list_filter = ['navigation_section', ]
    readonly_fields = ['date_created', 'date_modified']
    fieldsets = (
        (
            None,
            {
                'fields': (
                    ('pk', 'date_created', 'date_modified'),
                    ('title', ),
                ),
            },
        ),
        (
            'Overall',
            {
                'fields': (
                    'url_slug',
                    'internal_url',
                    'external_url',
                ),
                'description': "If this is a listing page from an apphook, put the \"name\" value from the urls.py file in the URL Slug field and leave External URL blank. Otherwise either put the partial URL in the Internal URL field (e.g., \'/about\'), or the complete URL in the external URL field."
            },
        ),
    )


class SiteParameterSwitchAdmin(BaseParameterAdmin):
    pass


class SiteParameterURLAdmin(BaseParameterAdmin):
    fieldsets = (
        (
            None,
            {
                'fields': (
                    ('pk', 'date_created', 'date_modified'), ('title', 'slug'),
                    ('value', 'new_window')
                ),
            },
        ),
    )


class SiteParameterIntegerAdmin(BaseParameterAdmin):
    pass


class SiteParameterTextAdmin(BaseParameterAdmin):
    pass


class SiteParameterStringAdmin(BaseParameterAdmin):
    pass


class SiteParameterImageAdmin(BaseParameterAdmin):
    exclude = ['image_height', 'image_width', 'image_ppoi']


class SiteSocialNetworkAdmin(BaseGenericStatusAdmin):
    prepopulated_fields = {"slug": ("service", )}
    list_display = ['pk', 'service', 'available', 'url', 'order_in_list']
    list_display_links = ('pk', 'service')
    ordering = ('order_in_list', )
    readonly_fields = ('date_created', 'date_modified', 'pk')
    actions = ['make_available', 'make_unavailable']

    fieldsets = [
        (
            None,
            {
                'fields': (
                    ('pk', 'available', 'date_created', 'date_modified'),
                    ('service', 'slug'),
                    ('title_on_service', ),
                    ('url', ),
                    ('order_in_list', ),
                )
            },
        ),
        (
            'Icon',
            {'fields': (('svg_path', ), ), 'classes': ('collapse', )},
        ),
    ]

    def get_readonly_fields(self, request, obj=None):
        if obj and not request.user.is_superuser:    # editing an existing object
            return self.readonly_fields + ('svg_path', )
        return self.readonly_fields


admin.site.register(SiteNavigationSection, SiteNavigationSectionAdmin)
admin.site.register(SiteParameterSwitch, SiteParameterSwitchAdmin)
admin.site.register(SiteParameterURL, SiteParameterURLAdmin)
admin.site.register(SiteParameterInteger, SiteParameterIntegerAdmin)
admin.site.register(SiteParameterText, SiteParameterTextAdmin)
admin.site.register(SiteParameterString, SiteParameterStringAdmin)
admin.site.register(SiteParameterImage, SiteParameterImageAdmin)
admin.site.register(SiteSocialNetwork, SiteSocialNetworkAdmin)
